@@ -2,6 +2,7 @@
 import re
 import os
 import requests
+import subprocess
 
 def readActions(format_inhalt_list, messanger="Telegram", asset_url=""):
     actions = []
@@ -54,10 +55,14 @@ def readActions(format_inhalt_list, messanger="Telegram", asset_url=""):
 
             match = re.search(regex, inhalt)
             if match:
-                action["url"] = os.path.join(asset_url, match.group('file'))
-                if requests.get(action["url"]).status_code != 200:
-                    print("Die angegebenen Datei ({}) konnte nicht unter der Asset URL ({}) gefunden werden.".format(
-                    match.group('file'), asset_url))
+                mp3_filename = os.path.join("assets/", match.group('file'))
+                ogg_filename = mp3_filename.replace(".mp3", ".ogg")
+                subprocess.run(["ffmpeg", '-i', mp3_filename, "-ac", "1", '-acodec', 'libopus', ogg_filename, '-y'])
+
+                if messanger=="Telegram":
+                    action["file"] = ogg_filename
+                else:
+                    action["url"] = os.path.join(asset_url, ogg_filename)
                 action["caption"] = match.group('name')
             else:
                 action["url"] = os.path.join(asset_url, "platzhalter.mp3")
